@@ -66,7 +66,7 @@ void command_open(gpointer callback_data,guint callback_action,
 	OpenFile *open_file;
 
 	command_open_file=NULL;
-	command_open_dialog=gtk_file_selection_new(_("ե򳫤"));
+	command_open_dialog=gtk_file_selection_new(_("Open"));
 	gtk_signal_connect(
 				GTK_OBJECT(command_open_dialog),"destroy",gtk_main_quit,NULL);
 	gtk_signal_connect(
@@ -78,7 +78,7 @@ void command_open(gpointer callback_data,guint callback_action,
 	if (open_path!=NULL)
 		gtk_file_selection_set_filename(
 							GTK_FILE_SELECTION(command_open_dialog),open_path);
-	command_open_check=gtk_check_button_new_with_label(_("Ϣ³ɤ߹"));
+	command_open_check=gtk_check_button_new_with_label(_("Continual"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(command_open_check),
 																file_merge);
 	gtk_box_pack_start(
@@ -113,7 +113,7 @@ void command_save(gpointer callback_data,guint callback_action,
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
 	command_open_file=NULL;
 	command_open_check=NULL;
-	command_open_dialog=gtk_file_selection_new(_("̾դ¸"));
+	command_open_dialog=gtk_file_selection_new(_("Save As"));
 	gtk_signal_connect(
 				GTK_OBJECT(command_open_dialog),"destroy",gtk_main_quit,NULL);
 	gtk_signal_connect(
@@ -369,7 +369,7 @@ void command_delete(gpointer callback_data,guint callback_action,
 			result=FALSE;
 	}
 	if (!result) {
-		message_box("Video maid",_("AVIʣǤޤ"),0,_("λ"),NULL);
+		message_box("Video maid",_("AVI Clone Error"),0,_("OK"),NULL);
 		for (i=0;i<2;i++)
 			if (d->avi[i]!=NULL)
 				avi_release(d->avi[i]);
@@ -413,7 +413,7 @@ void command_delete(gpointer callback_data,guint callback_action,
 		}
 	}
 	if (!result) {
-		message_box("Video maid",_("AVIǤޤ"),0,_("λ"),NULL);
+		message_box("Video maid",_("AVI Delete Error"),0,_("OK"),NULL);
 		for (i=0;i<2;i++) {
 			if (vmaid->avi[i]!=NULL)
 				avi_release(vmaid->avi[i]);
