@@ -42,8 +42,7 @@ void set_history(gchar *file)
 	GList *glist;
 	GtkWidget *sub_menu,*menu_item;
 
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
-														"<main>/ե(F)");
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
 	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
 	count=g_list_length(glist);
 	for (i=0;i<count-MENUFILE-1;i++) {
@@ -477,8 +476,7 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 	gtk_box_pack_start(GTK_BOX(xbox),vbox,FALSE,FALSE,0);
 	gtk_object_set_user_data(GTK_OBJECT(xbox),vmaid);
 	/* ˥塼 */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
-													_("<main>/ɥ(W)"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/Window");
 	vmaid->menu_item=gtk_menu_item_new_with_label(vmaid->file);
 	gtk_signal_connect(GTK_OBJECT(vmaid->menu_item),"activate",
 						GTK_SIGNAL_FUNC(signal_activate_menu_window),xbox);
