@@ -98,9 +98,9 @@ void draw_caret(VmaidWindow *vmaid,VmaidCursor *cursor)
 		timer_id=gtk_timeout_add(500,signal_timeout,NULL);
 	t=(gint64)vmaid->cursor.frame*vmaid->scale*1000/vmaid->rate;
 	text=vmaid->select.stream<0
-		?g_strdup_printf(_("ߤΥե졼 %d   %02d:%02d:%02d"),
+		?g_strdup_printf(_("Frame %d  Time %02d:%02d:%02d"),
 							vmaid->cursor.frame,t/60000%100,t/1000%60,t/10%100)
-		:g_strdup_printf(_("ߤΥե졼 %d  ϰ %d ... %d"),
+		:g_strdup_printf(_("Frame %d  Selected %d ... %d"),
 			vmaid->cursor.frame,
 			vmaid->select.frame-(vmaid->cursor.frame<vmaid->select.frame?1:0),
 			vmaid->cursor.frame-(vmaid->cursor.frame>vmaid->select.frame?1:0));
@@ -121,36 +121,36 @@ void set_menu_bar(VmaidWindow *vmaid)
 	if (vmaid!=NULL) {
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/Խ(E)"))),TRUE);
+				"<main>/Edit"))),TRUE);
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/ɽ(V)"))),TRUE);
+				"<main>/View"))),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/ե(F)/Ĥ(C)"),TRUE);
+				"<main>/File/Close"),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/ե(F)/̾Ĥ¸(A)..."),
+				"<main>/File/Save As..."),
 								vmaid->avi[0]!=NULL || vmaid->avi[1]!=NULL);
 //		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-//				"<main>/ե(F)/ץӥ塼(V)..."),
+//				"<main>/File/Preview..."),
 //								vmaid->avi[0]!=NULL || vmaid->avi[1]!=NULL);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/ե(F)/ץѥƥ(I)..."),
+				"<main>/File/Properties..."),
 								vmaid->avi[0]!=NULL || vmaid->avi[1]!=NULL);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/Խ(E)/᤹(U)"),vmaid->undo!=NULL);
+				"<main>/Edit/Undo"),vmaid->undo!=NULL);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/Խ(E)/ľ(R)"),vmaid->redo!=NULL);
+				"<main>/Edit/Redo"),vmaid->redo!=NULL);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/Խ(E)/ڤ(T)"),vmaid->select.stream>=0);
+				"<main>/Edit/Cut"),vmaid->select.stream>=0);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/Խ(E)/ԡ(C)"),vmaid->select.stream>=0);
+				"<main>/Edit/Copy"),vmaid->select.stream>=0);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/Խ(E)/(L)"),vmaid->select.stream>=0);
+				"<main>/Edit/Delete"),vmaid->select.stream>=0);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/Խ(E)/ե졼ذư(J)..."),
+				"<main>/Edit/Jump..."),
 								vmaid->avi[0]!=NULL || vmaid->avi[1]!=NULL);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/Խ(E)/٤(A)"),
+				"<main>/Edit/All"),
 								vmaid->avi[0]!=NULL || vmaid->avi[1]!=NULL);
 		gtk_widget_set_sensitive(toolbar_items[ 2].item,TRUE);
 		gtk_widget_set_sensitive(toolbar_items[ 4].item,
@@ -169,18 +169,18 @@ void set_menu_bar(VmaidWindow *vmaid)
 	} else {
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/Խ(E)"))),FALSE);
+				"<main>/Edit"))),FALSE);
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/ɽ(V)"))),FALSE);
+				"<main>/View"))),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/ե(F)/Ĥ(C)"),FALSE);
+				"<main>/File/Close"),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/ե(F)/̾Ĥ¸(A)..."),FALSE);
+				"<main>/File/Save As..."),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/ե(F)/ץӥ塼(V)..."),FALSE);
+				"<main>/File/Preview..."),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				"<main>/ե(F)/ץѥƥ(I)..."),FALSE);
+				"<main>/File/Properties..."),FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 2].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 4].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 6].item,FALSE);
@@ -191,7 +191,7 @@ void set_menu_bar(VmaidWindow *vmaid)
 		gtk_widget_set_sensitive(toolbar_items[13].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[14].item,FALSE);
 	}
-	menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/ɥ(W)");
+	menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/Window");
 	glist=gtk_container_children(GTK_CONTAINER(menu));
 	gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(menu)),
 													g_list_length(glist)>0);
@@ -450,11 +450,9 @@ gboolean prompt_close(VmaidWindow *vmaid)
 	gchar *text;
 
 	if (vmaid->edit) {
-		text=g_strdup_printf(
-					_("ե %s ƤѹƤޤ\n¸ޤ?"),
-																vmaid->file);
+		text=g_strdup_printf(_("File %s was edited.\nSave?"),vmaid->file);
 		switch (message_box("Video maid",text,0,
-							_("Ϥ(_Y)"),_("(_N)"),_(""),NULL)) {
+										_("_Yes"),_("_No"),_("Cancel"),NULL)) {
 			case 0:
 				command_save(NULL,0,NULL);
 				if (!vmaid->edit)
