@@ -82,13 +82,13 @@ gboolean jump_dialog(JumpDialog *jmp)
 
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_title(GTK_WINDOW(dialog),_("ե졼ذư"));
+	gtk_window_set_title(GTK_WINDOW(dialog),_("Jump"));
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 								GTK_SIGNAL_FUNC(jump_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
 	/* ܥ */
-	button0=gtk_button_new_with_label(_("λ"));
-	button1=gtk_button_new_with_label(_(""));
+	button0=gtk_button_new_with_label(_("OK"));
+	button1=gtk_button_new_with_label(_("Cancel"));
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",jump_dialog_clicked,jmp);
 	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
 										gtk_widget_destroy,GTK_OBJECT(dialog));
