@@ -17,6 +17,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <gdk/gdkkeysyms.h>
+#include <string.h>
 #include "prop.h"
 #include "other.h"
 
@@ -32,8 +33,8 @@ static GtkWidget *spin0,*spin1,*spin2,*spin3,*spin4,*radio0,*radio2;
 static struct {
 	gchar *text;
 	gint bit;
-} bit_count[]={{N_(""),1},{N_("16"),4},{N_("256"),8},
-	{N_("16ӥå"),16},{N_("ե륫顼"),24},{N_("32ӥå"),32},{NULL,0}};
+} bit_count[]={{N_("Monochrome"),1},{N_("16 colors"),4},{N_("256 colors"),8},
+	{N_("16 bits"),16},{N_("Full Color"),24},{N_("32 bits"),32},{NULL,0}};
 
 
 /* OKܥ󤬲줿 */
@@ -52,7 +53,7 @@ static void prop_dialog_clicked(GtkWidget *widget,PropertyDialog *prop)
 		prop->height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
 		text=gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry));
 		for (i=0;bit_count[i].text!=NULL;i++)
-			if (strcmp(_(bit_count[i].text),text)==0)
+			if (strcmp(gettext(bit_count[i].text),text)==0)
 				prop->bit_count=bit_count[i].bit;
 		prop->x_pixels_per_meter
 					=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2));
@@ -137,7 +138,7 @@ gboolean property_dialog(PropertyDialog *prop)
 
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_title(GTK_WINDOW(dialog),_("ץѥƥ"));
+	gtk_window_set_title(GTK_WINDOW(dialog),_("Property"));
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 								GTK_SIGNAL_FUNC(prop_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
@@ -145,8 +146,8 @@ gboolean property_dialog(PropertyDialog *prop)
 	accel=gtk_accel_group_new();
 	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
 	/* ܥ */
-	button0=gtk_button_new_with_label(_("λ"));
-	button1=gtk_button_new_with_label(_(""));
+	button0=gtk_button_new_with_label(_("OK"));
+	button1=gtk_button_new_with_label(_("Cancel"));
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",prop_dialog_clicked,prop);
 	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
 										gtk_widget_destroy,GTK_OBJECT(dialog));
@@ -163,13 +164,13 @@ gboolean property_dialog(PropertyDialog *prop)
 	gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
 	/* ٥ */
 	label0=gtk_label_new(NULL);
-	key=gtk_label_parse_uline(GTK_LABEL(label0),_("1ô֤Υե졼(_F)"));
+	key=gtk_label_parse_uline(GTK_LABEL(label0),_("_Frame per second"));
 	gtk_widget_add_accelerator(entry,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 
 	if (prop->width>0 && prop->height>0 && prop->bit_count!=0) {
 		/* ܥܥå */
 		for (i=0;bit_count[i].text!=NULL;i++)
-			glist=g_list_append(glist,_(bit_count[i].text));
+			glist=g_list_append(glist,gettext(bit_count[i].text));
 		combo=gtk_combo_new();
 		gtk_combo_set_popdown_strings(GTK_COMBO(combo),glist);
 		gtk_combo_set_value_in_list(GTK_COMBO(combo),TRUE,FALSE);
@@ -177,7 +178,7 @@ gboolean property_dialog(PropertyDialog *prop)
 		for (i=0;bit_count[i].text!=NULL;i++)
 			if (bit_count[i].bit==prop->bit_count)
 				gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo)->entry),
-														_(bit_count[i].text));
+												gettext(bit_count[i].text));
 		gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry),"changed",
 													prop_dialog_changed,prop);
 		/* ԥܥ */
@@ -219,19 +220,19 @@ gboolean property_dialog(PropertyDialog *prop)
 		label3=gtk_label_new(NULL);
 		label4=gtk_label_new(NULL);
 		label5=gtk_label_new(NULL);
-		key=gtk_label_parse_uline(GTK_LABEL(label1),_("(_W)"));
+		key=gtk_label_parse_uline(GTK_LABEL(label1),_("_Width"));
 		gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,
 															GDK_MOD1_MASK,0);
-		key=gtk_label_parse_uline(GTK_LABEL(label2),_("⤵(_H)"));
+		key=gtk_label_parse_uline(GTK_LABEL(label2),_("_Height"));
 		gtk_widget_add_accelerator(spin1,"grab-focus",accel,key,
 															GDK_MOD1_MASK,0);
-		key=gtk_label_parse_uline(GTK_LABEL(label3),_("(_C)"));
+		key=gtk_label_parse_uline(GTK_LABEL(label3),_("_Color"));
 		gtk_widget_add_accelerator(combo,"grab-focus",accel,key,
 															GDK_MOD1_MASK,0);
-		key=gtk_label_parse_uline(GTK_LABEL(label4),_("X(_X)"));
+		key=gtk_label_parse_uline(GTK_LABEL(label4),_("_X pixels per meter"));
 		gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,
 															GDK_MOD1_MASK,0);
-		key=gtk_label_parse_uline(GTK_LABEL(label5),_("Y(_Y)"));
+		key=gtk_label_parse_uline(GTK_LABEL(label5),_("_Y pixels per meter"));
 		gtk_widget_add_accelerator(spin1,"grab-focus",accel,key,
 															GDK_MOD1_MASK,0);
 
@@ -264,7 +265,7 @@ gboolean property_dialog(PropertyDialog *prop)
 		gtk_box_pack_start(GTK_BOX(hbox),spin3,TRUE,TRUE,0);
 		gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 
-		frame0=gtk_frame_new(_("ӥǥ"));
+		frame0=gtk_frame_new(_("Video"));
 		gtk_container_add(GTK_CONTAINER(frame0),vbox);
 	}
 
@@ -281,7 +282,7 @@ gboolean property_dialog(PropertyDialog *prop)
 													prop_dialog_changed,prop);
 		/* ٥ */
 		label6=gtk_label_new(NULL);
-		key=gtk_label_parse_uline(GTK_LABEL(label6),_("졼(_R)"));
+		key=gtk_label_parse_uline(GTK_LABEL(label6),_("_Rate"));
 		gtk_widget_add_accelerator(spin4,"grab-focus",accel,key,
 															GDK_MOD1_MASK,0);
 		/* 饸ܥ */
@@ -292,16 +293,16 @@ gboolean property_dialog(PropertyDialog *prop)
 		radio3=gtk_radio_button_new_with_label_from_widget(
 												GTK_RADIO_BUTTON(radio2),NULL);
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),
-															_("Υ(_M)"));
+															_("_Monophone"));
 		gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),
-															_("ƥ쥪(_S)"));
+																_("_Stereo"));
 		gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio2)->child),
-															_("8ӥå(_8)"));
+																_("_8 bits"));
 		gtk_widget_add_accelerator(radio2,"clicked",accel,key,GDK_MOD1_MASK,0);
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio3)->child),
-															_("16ӥå(_1)"));
+																_("_16 bits"));
 		gtk_widget_add_accelerator(radio3,"clicked",accel,key,GDK_MOD1_MASK,0);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
 										prop->channels==1?radio0:radio1),TRUE);
@@ -328,7 +329,7 @@ gboolean property_dialog(PropertyDialog *prop)
 		gtk_container_set_border_width(GTK_CONTAINER(hbox),8);
 		gtk_box_pack_start(GTK_BOX(hbox),radio0,FALSE,FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),radio1,FALSE,FALSE,0);
-		frame1=gtk_frame_new(_("ͥ"));
+		frame1=gtk_frame_new(_("Channel"));
 		gtk_container_add(GTK_CONTAINER(frame1),hbox);
 		gtk_box_pack_start(GTK_BOX(vbox),frame1,FALSE,FALSE,0);
 
@@ -336,11 +337,11 @@ gboolean property_dialog(PropertyDialog *prop)
 		gtk_container_set_border_width(GTK_CONTAINER(hbox),8);
 		gtk_box_pack_start(GTK_BOX(hbox),radio2,FALSE,FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),radio3,FALSE,FALSE,0);
-		frame1=gtk_frame_new(_("ӥå"));
+		frame1=gtk_frame_new(_("Bit"));
 		gtk_container_add(GTK_CONTAINER(frame1),hbox);
 		gtk_box_pack_start(GTK_BOX(vbox),frame1,FALSE,FALSE,0);
 
-		frame1=gtk_frame_new(_("ǥ"));
+		frame1=gtk_frame_new(_("Audio"));
 		gtk_container_add(GTK_CONTAINER(frame1),vbox);
 	}
 
