@@ -17,6 +17,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <gdk/gdkkeysyms.h>
+#include <string.h>
 #include "save.h"
 
 
@@ -87,7 +88,7 @@ static void save_dialog_toggled(GtkWidget *widget,SaveFile *save)
 /* ԥܥǥ꥿󤬲줿 */
 static void save_dialog_activate(GtkWidget *widget,SaveFile *save)
 {
-	gint start,end;
+	gint start=0,end=0;
 
 	if (frame1!=NULL) {
 		start=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
@@ -117,7 +118,7 @@ gboolean save_dialog(SaveFile *save)
 
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_title(GTK_WINDOW(dialog),_("̾դ¸"));
+	gtk_window_set_title(GTK_WINDOW(dialog),_("Save As"));
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 								GTK_SIGNAL_FUNC(save_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
@@ -125,8 +126,8 @@ gboolean save_dialog(SaveFile *save)
 	accel=gtk_accel_group_new();
 	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
 	/* ܥ */
-	button0=gtk_button_new_with_label(_("λ"));
-	button1=gtk_button_new_with_label(_(""));
+	button0=gtk_button_new_with_label(_("OK"));
+	button1=gtk_button_new_with_label(_("Cancel"));
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",save_dialog_clicked,save);
 	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
 										gtk_widget_destroy,GTK_OBJECT(dialog));
@@ -153,10 +154,10 @@ gboolean save_dialog(SaveFile *save)
 		/* ٥ */
 		label0=gtk_label_new(NULL);
 		label1=gtk_label_new(NULL);
-		key=gtk_label_parse_uline(GTK_LABEL(label0),_("(_S)"));
+		key=gtk_label_parse_uline(GTK_LABEL(label0),_("_Start"));
 		gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,
 															GDK_MOD1_MASK,0);
-		key=gtk_label_parse_uline(GTK_LABEL(label1),_("λ(_E)"));
+		key=gtk_label_parse_uline(GTK_LABEL(label1),_("_End"));
 		gtk_widget_add_accelerator(spin1,"grab-focus",accel,key,
 															GDK_MOD1_MASK,0);
 		/* 饸ܥ */
@@ -164,10 +165,10 @@ gboolean save_dialog(SaveFile *save)
 		radio1=gtk_radio_button_new_with_label_from_widget(
 												GTK_RADIO_BUTTON(radio0),NULL);
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),
-																_("AVI(_A)"));
+																_("_AVI"));
 		gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),
-														_("ӥåȥޥå(_B)"));
+																_("_Bitmap"));
 		gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
 		gtk_signal_connect(GTK_OBJECT(radio0),"toggled",
 									GTK_SIGNAL_FUNC(save_dialog_toggled),save);
@@ -187,7 +188,7 @@ gboolean save_dialog(SaveFile *save)
 		gtk_box_pack_start(GTK_BOX(hbox),label1,FALSE,FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),spin1,TRUE,TRUE,0);
 		gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
-		frame1=gtk_frame_new(_("ϰ"));
+		frame1=gtk_frame_new(_("Range"));
 	gtk_container_add(GTK_CONTAINER(frame1),vbox);
 	} else {
 		frame1=label0=label1=spin0=spin1=radio0=radio1=NULL;
@@ -197,7 +198,7 @@ gboolean save_dialog(SaveFile *save)
 		/* 饸ܥ */
 		radio2=gtk_radio_button_new_with_label(glist,NULL);
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio2)->child),
-																_("WAVE(_W)"));
+																_("_WAVE"));
 		gtk_widget_add_accelerator(radio2,"clicked",accel,key,GDK_MOD1_MASK,0);
 		gtk_signal_connect(GTK_OBJECT(radio2),"toggled",
 									GTK_SIGNAL_FUNC(save_dialog_toggled),save);
@@ -208,7 +209,7 @@ gboolean save_dialog(SaveFile *save)
 	/* 饸ܥ */
 	radio3=gtk_radio_button_new_with_label(glist,NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio3)->child),
-												_("ʥꥪ֥(_O)"));
+														_("Scenario _Object"));
 	gtk_widget_add_accelerator(radio3,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_signal_connect(GTK_OBJECT(radio3),"toggled",
 									GTK_SIGNAL_FUNC(save_dialog_toggled),save);
@@ -223,7 +224,7 @@ gboolean save_dialog(SaveFile *save)
 	if (radio2!=NULL)
 		gtk_box_pack_start(GTK_BOX(vbox),radio2,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(vbox),radio3,FALSE,FALSE,0);
-	frame0=gtk_frame_new(_(""));
+	frame0=gtk_frame_new(_("Format"));
 	gtk_container_add(GTK_CONTAINER(frame0),vbox);
 
 	vbox=gtk_vbox_new(FALSE,8);
