@@ -19,6 +19,7 @@
 #include <pthread.h>
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
+#include "argument.h"
 #include "avicore.h"
 #include "command.h"
 #include "file.h"
@@ -504,15 +505,13 @@ gboolean signal_button_press(GtkWidget *widget,GdkEventButton *event,
 			break;
 		case 3:/* å */
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,"<main>/᤹(U)"),vmaid->undo!=NULL);
+				item_factory_popup,"<main>/Undo"),vmaid->undo!=NULL);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,"<main>/ڤ(T)"),
-													vmaid->select.stream>=0);
+				item_factory_popup,"<main>/Cut"),vmaid->select.stream>=0);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,"<main>/ԡ(C)"),
-													vmaid->select.stream>=0);
+				item_factory_popup,"<main>/Copy"),vmaid->select.stream>=0);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,"<main>/(L)"),vmaid->select.stream>=0);
+				item_factory_popup,"<main>/Delete"),vmaid->select.stream>=0);
 			gtk_menu_popup(GTK_MENU(
 					gtk_item_factory_get_widget(item_factory_popup,"<main>")),
 								NULL,NULL,NULL,NULL,event->button,event->time);
@@ -880,15 +879,13 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,
 							vmaid,0,get_max_frame(vmaid,-1)+1,sx,vmaid->top);
 			clear_sel(vmaid,&vmaid->cursor,&vmaid->select,top);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,"<main>/᤹(U)"),vmaid->undo!=NULL);
+				item_factory_popup,"<main>/Undo"),vmaid->undo!=NULL);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,"<main>/ڤ(T)"),
-													vmaid->select.stream>=0);
+				item_factory_popup,"<main>/Cut"),vmaid->select.stream>=0);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,"<main>/ԡ(C)"),
-													vmaid->select.stream>=0);
+				item_factory_popup,"<main>/Copy"),vmaid->select.stream>=0);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,"<main>/(L)"),vmaid->select.stream>=0);
+				item_factory_popup,"<main>/Delete"),vmaid->select.stream>=0);
 			gtk_menu_popup(GTK_MENU(
 					gtk_item_factory_get_widget(item_factory_popup,"<main>")),
 											NULL,NULL,NULL,NULL,3,event->time);
@@ -935,8 +932,7 @@ void signal_destroy_draw(GtkWidget *widget,VmaidWindow *vmaid)
 	/* ե̾Ĵ٤ */
 	delete_edit_file(vmaid->file);
 	/* ɥ˥塼 */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
-													"<main>/ɥ(W)");
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/Window");
 	gtk_container_remove(GTK_CONTAINER(sub_menu),vmaid->menu_item);
 	/* ˥塼 */
 	glist=gtk_container_children(GTK_CONTAINER(notebook));
@@ -1077,8 +1073,7 @@ void signal_select_row(GtkWidget *widget,gint row,gint column,
 									GdkEventButton *event,gpointer user_data)
 {
 	gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
-								gtk_item_factory_get_widget(item_factory_menu,
-												"<main>/(T)"))),TRUE);
+		gtk_item_factory_get_widget(item_factory_menu,"<main>/Task"))),TRUE);
 }
 
 
@@ -1095,7 +1090,7 @@ void signal_unselect_row(GtkWidget *widget,gint row,gint column,
 	if (i==GTK_CLIST(clist)->rows)
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-												"<main>/(T)"))),FALSE);
+													"<main>/Task"))),FALSE);
 }
 
 
@@ -1129,6 +1124,7 @@ gboolean signal_selection_clear(GtkWidget *widget,GdkEventSelection *event,
 															gpointer user_data)
 {
 	if (event->selection==atom_clipboard) {
+		/* åץܡ */
 		g_free(clipboard_scenario);
 		clipboard_scenario=NULL;
 	}
@@ -1144,13 +1140,21 @@ void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
 	if (data->selection==atom_clipboard) {
 		/* åץܡ */
 		if (clipboard_scenario!=NULL && info==TARGET_VMAID)
-			gtk_selection_data_set(data,atom_scenario,8*sizeof(gchar),
+			gtk_selection_data_set(data,atom_scenario,8,
 					(guchar *)clipboard_scenario,strlen(clipboard_scenario));
-	} else if (data->selection==atom_videomaid) {
+	} else if (data->selection==atom_videomaid0) {
 		/* ץ̿ */
 		text="Video maid Selection";
-		gtk_selection_data_set(data,GDK_SELECTION_TYPE_STRING,
-								8*sizeof(gchar),(guchar *)text,strlen(text));
+		gtk_selection_data_set(data,GDK_SELECTION_TYPE_STRING,8,
+												(guchar *)text,strlen(text));
+		gtk_selection_convert(window,atom_videomaid1,
+								GDK_SELECTION_TYPE_STRING,GDK_CURRENT_TIME);
+	} else if (data->selection==atom_videomaid1 && arg_text!=NULL) {
+		/* ץ̿ */
+		gtk_selection_data_set(data,GDK_SELECTION_TYPE_STRING,8,
+										(guchar *)arg_text,strlen(arg_text));
+		g_free(arg_text);
+		arg_text=NULL;
 	}
 }
 
@@ -1158,12 +1162,15 @@ void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
 void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 												guint time,gpointer user_data)
 {
-	gboolean result=TRUE,paste[2];
+	gboolean result=TRUE,paste[2],*arg_files;
+	gchar **argv;
 	gint i,count,max,sx;
+	pthread_t id;
 	AviEdit **avi;
+	OpenFile *open_file;
+	GdkAtom *atoms;
 	VmaidWindow *vmaid;
 	VmaidHistory *d;
-	GdkAtom *atoms;
 
 	if (data->selection==atom_clipboard) {
 		/* åץܡ */
@@ -1194,8 +1201,8 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 							result=FALSE;
 					}
 					if (!result) {
-						message_box("Video maid",_("AVIʣǤޤ"),0,
-															_("λ"),NULL);
+						message_box("Video maid",_("AVI Clone Error"),0,
+																_("OK"),NULL);
 						for (i=0;i<2;i++)
 							if (d->avi[i]!=NULL)
 								avi_release(d->avi[i]);
@@ -1256,8 +1263,8 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 					}
 				g_free(avi);
 				if (!result || (!paste[0] && !paste[1])) {
-					message_box("Video maid",_("AVIŽդǤޤ"),0,
-															_("λ"),NULL);
+					message_box("Video maid",_("AVI Paste Error"),0,
+																_("OK"),NULL);
 					for (i=0;i<2;i++)
 						if (vmaid->avi[i]!=NULL)
 							avi_release(vmaid->avi[i]);
@@ -1297,9 +1304,24 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 				vmaid->edit=TRUE;
 			}
 		}
-	} else if (data->selection==atom_videomaid) {
+	} else if (data->selection==atom_videomaid0) {
 		/* ץ̿ */
 		instance=MAX(data->length,0);
+	} else if (data->selection==atom_videomaid1) {
+		/* ץ̿ */
+		/* ޥɥ饤β */
+		argv=g_strsplit(data->data,"\n",G_MAXINT);
+		arg_files=arg_analyse(argv,FALSE);
+		for (i=0;argv[i]!=NULL;i++)
+			if (arg_files[i]) {
+				open_file=g_malloc(sizeof(OpenFile));
+				open_file->file=g_strdup(argv[i]);
+				open_file->merge=file_merge;
+				pthread_create(&id,NULL,(void *)open_edit_file,open_file);
+				pthread_detach(id);
+			}
+		g_free(arg_files);
+		g_strfreev(argv);
 	}
 }
 
@@ -1309,62 +1331,6 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 * ʥ/٥ȴؿ(ᥤ)                                             *
 *                                                                             *
 ******************************************************************************/
-gboolean signal_client_event(GtkWidget *widget,GdkEventClient *event,
-															gpointer user_data)
-{
-	gint i;
-	pthread_t id;
-	OpenFile *open_file;
-	VmaidCommunication *p;
-
-	if (event->message_type==atom_videomaid) {
-		for (p=comm;p!=NULL;p=p->next)
-			if (p->pid==event->data.l[4])
-				break;
-		if (p==NULL) {
-			p=g_malloc(sizeof(VmaidCommunication));
-			p->arg=NULL;
-			p->leng=0;
-			p->init_line=0;
-			p->pid=event->data.l[4];
-			p->prev=NULL;
-			p->next=comm;
-			if (p->next!=NULL)
-				p->next->prev=p;
-			comm=p;
-		}
-		switch (event->data_format) {
-			case 8:
-				p->arg=g_realloc(p->arg,p->leng+16);
-				memcpy(p->arg+p->leng,event->data.b,16);
-				p->leng+=16;
-				for (i=0;i<16;i++)
-					if (event->data.b[i]=='\0')
-						break;
-				if (i<16) {
-					open_file=g_malloc(sizeof(OpenFile));
-					open_file->file=p->arg;
-					open_file->merge=file_merge;
-					pthread_create(&id,NULL,(void *)open_edit_file,open_file);
-					pthread_detach(id);
-					if (p->prev!=NULL)
-						p->prev->next=p->next;
-					if (p->next!=NULL)
-						p->next->prev=p->prev;
-					if (comm==p)
-						comm=comm->next;
-					g_free(p);
-				}
-				break;
-			case 32:
-				p->init_line=event->data.l[0];
-		}
-		return TRUE;
-	}
-	return FALSE;
-}
-
-
 gboolean signal_delete(GtkWidget *widget,GdkEvent *event,gpointer user_data)
 {
 	gint page;
@@ -1391,8 +1357,7 @@ void signal_destroy_window(GtkWidget *widget,gpointer user_data)
 	GtkWidget *sub_menu;
 
 	memset(history_file,0,sizeof(gchar *)*10);
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
-														"<main>/ե(F)");
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
 	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
 	for (i=0;i<(gint)g_list_length(glist)-MENUFILE-1;i++)
 		history_file[i]=g_strdup(gtk_object_get_user_data(
