@@ -145,7 +145,7 @@ gboolean size_dialog(SizeDialog *size)
 
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_title(GTK_WINDOW(dialog),_("ѹ"));
+	gtk_window_set_title(GTK_WINDOW(dialog),_("Size"));
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 								GTK_SIGNAL_FUNC(size_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
@@ -154,7 +154,7 @@ gboolean size_dialog(SizeDialog *size)
 	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
 	/* ܥ */
 	if (size->def_width>0 && size->def_height>0) {
-		button0=gtk_button_new_with_label(_("ɸ"));
+		button0=gtk_button_new_with_label(_("Standard"));
 		button1=gtk_button_new_with_label(_("1/2"));
 		button2=gtk_button_new_with_label(_("1/4"));
 		button3=gtk_button_new_with_label(_("1/8"));
@@ -177,12 +177,12 @@ gboolean size_dialog(SizeDialog *size)
 	} else {
 		button0=button1=button2=button3=NULL;
 	}
-	button4=gtk_button_new_with_label(_("320240"));
-	button5=gtk_button_new_with_label(_("160120"));
-	button6=gtk_button_new_with_label(_("8060"));
-	button7=gtk_button_new_with_label(_("4030"));
-	button8=gtk_button_new_with_label(_("λ"));
-	button9=gtk_button_new_with_label(_(""));
+	button4=gtk_button_new_with_label(_("320\xd7240"));
+	button5=gtk_button_new_with_label(_("160\xd7120"));
+	button6=gtk_button_new_with_label(_("80\xd760"));
+	button7=gtk_button_new_with_label(_("40\xd730"));
+	button8=gtk_button_new_with_label(_("OK"));
+	button9=gtk_button_new_with_label(_("Cancel"));
 	gtk_object_set_user_data(GTK_OBJECT(button4),(gpointer)4);
 	gtk_object_set_user_data(GTK_OBJECT(button5),(gpointer)5);
 	gtk_object_set_user_data(GTK_OBJECT(button6),(gpointer)6);
@@ -209,7 +209,7 @@ gboolean size_dialog(SizeDialog *size)
 	if (size->def_width>0 && size->def_height>0) {
 		check=gtk_check_button_new_with_label(NULL);
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
-											_("/Ψݻʤ(_A)"));
+													_("_Allow distortion"));
 		gtk_widget_add_accelerator(check,"clicked",accel,key,GDK_MOD1_MASK,0);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),size->ratio);
 	} else {
@@ -231,9 +231,9 @@ gboolean size_dialog(SizeDialog *size)
 	/* ٥ */
 	label0=gtk_label_new(NULL);
 	label1=gtk_label_new(NULL);
-	key=gtk_label_parse_uline(GTK_LABEL(label0),_("(_W)"));
+	key=gtk_label_parse_uline(GTK_LABEL(label0),_("_Width"));
 	gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(label1),_("⤵(_H)"));
+	key=gtk_label_parse_uline(GTK_LABEL(label1),_("_Height"));
 	gtk_widget_add_accelerator(spin1,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 	/* ơ֥ */
 	if (button0!=NULL && button1!=NULL && button2!=NULL && button3!=NULL) {
