@@ -37,8 +37,8 @@ static volatile gint critical=FALSE;
 gboolean thread_insert(pthread_t id,gint mode,gchar *file)
 {
 	gchar *text[4];
-	gchar *mode_name[]={N_("λ"),N_(""),N_("¸"),N_("ե졼ѹ"),
-																N_("ȿž")};
+	gchar *mode_name[]={N_("Exit"),N_("Open"),N_("Save"),N_("Change Frames"),
+																N_("Reverse")};
 	time_t tm;
 	ThreadList *tl;
 
@@ -98,7 +98,7 @@ gboolean thread_idling(pthread_t id,gint percent)
 	if (tl->userbreak && tl->percent!=percent) {
 		/* ǤǤϤʤĿʹԾۤʤȤ */
 		tl->percent=percent;
-		text=percent>=0?g_strdup_printf("%d",percent):g_strdup(_("顼"));
+		text=percent>=0?g_strdup_printf("%d",percent):g_strdup(_("Error"));
 		gtk_clist_set_text(GTK_CLIST(clist),i,3,text);
 		g_free(text);
 		gtk_clist_set_column_width(GTK_CLIST(clist),3,
