@@ -19,9 +19,10 @@
 #include <ctype.h>
 #include <locale.h>
 #include <pthread.h>
-#include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
 #include "vmaid.h"
+#include "argument.h"
 #include "command.h"
 #include "conf.h"
 #include "file.h"
@@ -43,17 +44,18 @@ gchar *history_file[10];			/* ե */
 gchar *open_path=NULL;				/* Υѥ */
 gchar *save_path=NULL;				/* ̾դ¸Υѥ */
 gchar *clipboard_scenario=NULL;		/* åץܡɤΥƥ */
+gchar *arg_text=NULL;				/* ץ̿ѿ */
 gint def_width,def_height;			/* ǥեȤΥɥΥ */
 gint history=4;						/* ե */
 gint instance=-1;					/* ץ̿ѿ */
 gint default_view=6;				/* ɥν */
 guint default_rate=15;				/* ɥν */
 guint timer_id=0;					/* ID */
-VmaidCommunication *comm=NULL;		/* ץ̿ѹ¤ */
 GdkAtom atom_clipboard;				/* åץܡ */
 GdkAtom atom_targets;				/* å */
 GdkAtom atom_scenario;				/* ʥꥪ֥ */
-GdkAtom atom_videomaid;				/* ץ̿ѥȥ */
+GdkAtom atom_videomaid0;			/* ץ̿ѥȥ */
+GdkAtom atom_videomaid1;			/* ץ̿ѥȥ */
 GdkBitmap *bitmap0;					/* ط */
 GdkBitmap *bitmap1;					/* ط */
 GtkWidget *window;					/* ɥ */
@@ -88,79 +90,62 @@ static gchar *menu_translate(const gchar *path,gpointer func_data)
 int main(int argc,char *argv[])
 {
 	gboolean *arg_files;
-	gchar *arg,*endptr,*str,*key;
-	gint i,j,k,l,m,opt,leng,ascent,height;
+	gchar *arg,*key;
+	gint i,count=0,ascent,height,leng,length=0;
 	pthread_t id;
 	OpenFile *open_file;
 	PROFILE *profile;
-	GdkEventClient event;
 	GdkBitmap *mask;
 	GdkPixmap *pixmap;
 	GtkAccelGroup *accel_group;
 	GtkStyle *style;
 	GtkWidget *menubar,*toolbar,*text,*handle,*scroll,*vbox;
 	GtkWidget *sub_menu,*menu_item;
-	VmaidCommunication *p;
-	gchar *title[4]={N_("⡼"),N_("ե"),N_(""),N_("ʹԾ")};
+	gchar *title[4]={N_("Mode"),N_("File"),N_("Time"),N_("Status")};
 	GtkItemFactoryEntry menu_items[]={
-{N_("/ե(_F)"),                       NULL,         NULL,            0,"<Branch>"},
-{N_("/ե(F)/(_N)"),           "<control>N", command_new,     0,"<Item>"},
-{N_("/ե(F)/(_O)..."),            "<control>O", command_open,    0,"<Item>"},
-{N_("/ե(F)/Ĥ(_C)"),             "<control>W", command_close,   0,"<Item>"},
-{N_("/ե(F)/̾Ĥ¸(_A)..."),"<control>S", command_save,    0,"<Item>"},
-{N_("/ե(F)/Sep1"),                   NULL,         NULL,            0,"<Separator>"},
-{N_("/ե(F)/ץӥ塼(_V)..."),      "<control>P", NULL,            0,"<Item>"},
-{N_("/ե(F)/ץѥƥ(_I)..."),      "<alt>Return",command_property,0,"<Item>"},
-{N_("/ե(F)/Sep2"),                   NULL,         NULL,            0,"<Separator>"},
-{N_("/ե(F)/λ(_X)"),               "<control>Q", command_exit,    0,"<Item>"},
-{N_("/Խ(_E)"),                           NULL,         NULL,            0,"<Branch>"},
-{N_("/Խ(E)/᤹(_U)"),               "<control>Z", command_undo,    0,"<Item>"},
-{N_("/Խ(E)/ľ(_R)"),               "F4",         command_redo,    0,"<Item>"},
-{N_("/Խ(E)/Sep1"),                       NULL,         NULL,            0,"<Separator>"},
-{N_("/Խ(E)/ڤ(_T)"),               "<control>X", command_cut,     0,"<Item>"},
-{N_("/Խ(E)/ԡ(_C)"),                 "<control>C", command_copy,    0,"<Item>"},
-{N_("/Խ(E)/Žդ(_P)"),               "<control>V", command_paste,   0,"<Item>"},
-{N_("/Խ(E)/(_L)"),                   NULL,         command_delete,  0,"<Item>"},
-{N_("/Խ(E)/Sep2"),                       NULL,         NULL,            0,"<Separator>"},
-{N_("/Խ(E)/Ϣ(_M)..."),                "<control>M", NULL,            0,"<Item>"},
-{N_("/Խ(E)/ե졼ذư(_J)..."),  "<control>J", command_jump,    0,"<Item>"},
-{N_("/Խ(E)/Sep3"),                       NULL,         NULL,            0,"<Separator>"},
-{N_("/Խ(E)/٤(_A)"),             "<control>A", command_all,     0,"<Item>"},
-{N_("/ɽ(_V)"),                           NULL,         NULL,            0,"<Branch>"},
-{N_("/ɽ(V)/ѹ(_I)..."),          NULL,         command_size,    0,"<Item>"},
-{N_("/ץ(_O)"),                     NULL,         NULL,            0,"<Branch>"},
-{N_("/ץ(O)/(_C)..."),          NULL,         conf_dialog,     0,"<Item>"},
-{N_("/(_T)"),                         NULL,         NULL,            0,"<Branch>"},
-{N_("/(T)/(_C)"),                 NULL,         command_cancel,  0,"<Item>"},
-{N_("/ɥ(_W)"),                     NULL,         NULL,            0,"<Branch>"},
-{N_("/إ(_H)"),                         NULL,         NULL,            0,"<Branch>"},
-{N_("/إ(H)/С(_A)..."),    NULL,         version_dialog,  0,"<Item>"}};
+{N_("/_File"),                   NULL,         NULL,            0,"<Branch>"},
+{N_("/File/_New"),               "<control>N", command_new,     0,"<Item>"},
+{N_("/File/_Open..."),           "<control>O", command_open,    0,"<Item>"},
+{N_("/File/_Close"),             "<control>W", command_close,   0,"<Item>"},
+{N_("/File/Save _As..."),        "<control>S", command_save,    0,"<Item>"},
+{N_("/File/Sep1"),               NULL,         NULL,            0,"<Separator>"},
+{N_("/File/Pre_view..."),        "<control>P", NULL,            0,"<Item>"},
+{N_("/File/Propert_ies..."),     "<alt>Return",command_property,0,"<Item>"},
+{N_("/File/Sep2"),               NULL,         NULL,            0,"<Separator>"},
+{N_("/File/E_xit"),              "<control>Q", command_exit,    0,"<Item>"},
+{N_("/_Edit"),                   NULL,         NULL,            0,"<Branch>"},
+{N_("/Edit/_Undo"),              "<control>Z", command_undo,    0,"<Item>"},
+{N_("/Edit/_Redo"),              "F4",         command_redo,    0,"<Item>"},
+{N_("/Edit/Sep1"),               NULL,         NULL,            0,"<Separator>"},
+{N_("/Edit/Cu_t"),               "<control>X", command_cut,     0,"<Item>"},
+{N_("/Edit/_Copy"),              "<control>C", command_copy,    0,"<Item>"},
+{N_("/Edit/_Paste"),             "<control>V", command_paste,   0,"<Item>"},
+{N_("/Edit/De_lete"),            NULL,         command_delete,  0,"<Item>"},
+{N_("/Edit/Sep2"),               NULL,         NULL,            0,"<Separator>"},
+{N_("/Edit/_Merge..."),          "<control>M", NULL,            0,"<Item>"},
+{N_("/Edit/_Jump..."),           "<control>J", command_jump,    0,"<Item>"},
+{N_("/Edit/Sep3"),               NULL,         NULL,            0,"<Separator>"},
+{N_("/Edit/_All"),               "<control>A", command_all,     0,"<Item>"},
+{N_("/_View"),                   NULL,         NULL,            0,"<Branch>"},
+{N_("/View/S_ize..."),           NULL,         command_size,    0,"<Item>"},
+{N_("/_Option"),                 NULL,         NULL,            0,"<Branch>"},
+{N_("/Option/_Configuration..."),NULL,         conf_dialog,     0,"<Item>"},
+{N_("/_Task"),                   NULL,         NULL,            0,"<Branch>"},
+{N_("/Task/_Cancel"),            NULL,         command_cancel,  0,"<Item>"},
+{N_("/_Window"),                 NULL,         NULL,            0,"<Branch>"},
+{N_("/_Help"),                   NULL,         NULL,            0,"<Branch>"},
+{N_("/Help/_About..."),          NULL,         version_dialog,  0,"<Item>"}};
 	GtkItemFactoryEntry popup_items[]={
-{N_("/᤹(_U)"),                       "<control>Z", NULL,            0,"<Item>"},
-{"/Sep1",                                   NULL,         NULL,            0,"<Separator>"},
-{N_("/ڤ(_T)"),                       "<control>X", NULL,            0,"<Item>"},
-{N_("/ԡ(_C)"),                         "<control>C", NULL,            0,"<Item>"},
-{N_("/Žդ(_P)"),                       "<control>V", NULL,            0,"<Item>"},
-{N_("/(_L)"),                           NULL,         NULL,            0,"<Item>"},
-{"/Sep2",                                   NULL,         NULL,            0,"<Separator>"},
-{N_("/٤(_A)"),                     "<control>A", NULL,            0,"<Item>"}};
+{N_("/_Undo"),                   "<control>Z", NULL,            0,"<Item>"},
+{"/Sep1",                        NULL,         NULL,            0,"<Separator>"},
+{N_("/Cu_t"),                    "<control>X", NULL,            0,"<Item>"},
+{N_("/_Copy"),                   "<control>C", NULL,            0,"<Item>"},
+{N_("/_Paste"),                  "<control>V", NULL,            0,"<Item>"},
+{N_("/De_lete"),                 NULL,         NULL,            0,"<Item>"},
+{"/Sep2",                        NULL,         NULL,            0,"<Separator>"},
+{N_("/_All"),                    "<control>A", NULL,            0,"<Item>"}};
 	/* Drag&Drop */
 	GtkTargetEntry drag_types[1]={{"text/uri-list",0,0}};
-	/* ޥɥ饤  */
-	struct arg_opt {
-		const char *name;
-		const int key;
-		const char *arg;
-		const char *doc;
-	};
-	const struct arg_opt arg_opts[]={
-	{"history",'h',"NUM",         N_("ե")},
-	{"new",    'n',"ON/OFF",      N_("ե򳫤")},
-	{"size",   's',"WIDTH,HEIGHT",N_("ɥΥ")},
-	{"second", 'x',"ON/OFF",      N_("ɥ򳫤")},
-	{"version",'v',NULL,          N_("С")},
-	{"help",   '?',NULL,          N_("إ")},
-	{NULL,     0,  NULL,          NULL}};
 	static gchar *xpm0[]={
 "4 8 2 1",
 " 	c None",
@@ -244,103 +229,9 @@ int main(int argc,char *argv[])
 		}
 		profile_close(profile);
 	}
+
 	/* ޥɥ饤β */
-	arg_files=g_malloc(argc*sizeof(gboolean));
-	memset(arg_files,0,argc*sizeof(gboolean));
-	i=1;/* i:Υץ,j:iʸ,k:iʹߤarg */
-	while (i<argc) {
-		if ((argv[i])[0]=='-') {/* ץ */
-			j=1;
-			k=i;
-			while ((argv[i])[j]!='\0' && (argv[i])[j]!='=') {
-				if ((argv[i])[1]=='-') {	/* Ĺץ */
-					opt=0;
-					for (l=0;arg_opts[l].name!=NULL;l++) {
-						leng=strlen(arg_opts[l].name);
-						if (g_strncasecmp(argv[i]+2,arg_opts[l].name,leng)==0
-											&& ((argv[i])[leng+2]=='\0'
-												|| (argv[i])[leng+2]=='=')) {
-							opt=arg_opts[l].key;
-							j=leng+2;
-							break;
-						}
-					}
-				} else {					/* ûץ */
-					opt=tolower((argv[i])[j++]);
-				}
-				arg=NULL;
-				for (l=0;arg_opts[l].name!=NULL;l++)
-					if (arg_opts[l].key==opt && arg_opts[l].arg!=NULL) {
-						if (i==k) {
-							for (m=2;(argv[i])[m]!='\0' && (argv[i])[m]!='=';
-																		m++);
-							arg=(argv[i])[m]=='\0'?argv[++k]:argv[i]+m+1;
-							k++;
-						} else {
-							arg=argv[k++];
-						}
-						if (arg==NULL || *arg=='\0')
-							opt=0;
-						break;
-					}
-				switch (opt) {
-					case 'h':
-						strval(&history,arg,10,TRUE);
-						if (history<0)
-							history=0;
-						else if (history>10)
-							history=10;
-						break;
-					case 'n':
-						newfile=g_strcasecmp(arg,"OK")==0
-												|| g_strcasecmp(arg,"ON")==0
-												|| g_strcasecmp(arg,"TRUE")==0
-												|| g_strcasecmp(arg,"YES")==0;
-						break;
-					case 's':
-						def_width=strtol(arg,&endptr,0);
-						def_height=strtol(++endptr,&endptr,0);
-						break;
-					case 'x':
-						second=g_strcasecmp(arg,"OK")==0
-												|| g_strcasecmp(arg,"ON")==0
-												|| g_strcasecmp(arg,"TRUE")==0
-												|| g_strcasecmp(arg,"YES")==0;
-						break;
-					case 'v':
-						g_print(
-"Video maid "VERSION"\n"
-"Copyright (C) 1998-2002 Iwamoto,Kazuki\n"
-"This is free software; see the source for copying conditions.  There is NO\n"
-"warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
-						);
-						g_free(arg_files);
-						return 0;
-					default:
-						g_print(
-"Copyright (c) 1998-2002 Iwamoto,Kazuki\n\n"
-"Usage: %s [OPTION...] [FILE...]\n\n",argv[0]);
-						for (i=0;arg_opts[i].name;i++) {
-							if (arg_opts[i].arg!=NULL)
-								str=g_strdup_printf("  -%c, --%s=%s",
-											arg_opts[i].key,arg_opts[i].name,
-															arg_opts[i].arg);
-							else
-								str=g_strdup_printf("  -%c, --%s",
-											arg_opts[i].key, arg_opts[i].name);
-							g_print("%-26s %s\n",str,arg_opts[i].doc);
-							g_free(str);
-						}
-						g_print("\n");
-						g_free(arg_files);
-						return 0;
-				}
-			}
-			i=i<k?k:i+1;
-		} else {/* ե */
-			arg_files[i++]=TRUE;
-		}
-	}
+	arg_files=arg_analyse(argv+1,TRUE);
 
 	/* ᥤ󥦥ɥ */
 	window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -361,12 +252,16 @@ int main(int argc,char *argv[])
 	atom_clipboard=gdk_atom_intern("CLIPBOARD",FALSE);
 	atom_targets=gdk_atom_intern("TARGETS",FALSE);
 	atom_scenario=gdk_atom_intern("Video maid Scenario Object",FALSE);
-	atom_videomaid=gdk_atom_intern("Video maid InterProcess communication",
+	atom_videomaid0=gdk_atom_intern("Video maid InterProcess communication 0",
+																		FALSE);
+	atom_videomaid1=gdk_atom_intern("Video maid InterProcess communication 1",
 																		FALSE);
 	gtk_selection_add_targets(window,atom_clipboard,
 				targets_vmaid,sizeof(targets_vmaid)/sizeof(GtkTargetEntry));
-	if (!second)
-		gtk_selection_add_targets(window,atom_videomaid,targets_comm,1);
+	if (!second) {
+		gtk_selection_add_targets(window,atom_videomaid0,targets_comm,1);
+		gtk_selection_add_targets(window,atom_videomaid1,targets_comm,1);
+	}
 	gtk_signal_connect(GTK_OBJECT(window),"selection-clear-event",
 								GTK_SIGNAL_FUNC(signal_selection_clear),NULL);
 	gtk_signal_connect(GTK_OBJECT(window),"selection-get",
@@ -413,7 +308,9 @@ int main(int argc,char *argv[])
 						toolbar_items[i].callback,toolbar_items[i].user_data);
 		}
 	/* ꥹȥܥå */
-	clist=gtk_clist_new_with_titles(4,title);
+	clist=gtk_clist_new(4);
+	for (i=0;i<4;i++)
+		gtk_clist_set_column_title(GTK_CLIST(clist),i,gettext(title[i]));
 	gtk_clist_column_titles_show(GTK_CLIST(clist));
 	gtk_clist_column_titles_passive(GTK_CLIST(clist));
 	gtk_clist_set_column_justification(GTK_CLIST(clist),3,GTK_JUSTIFY_RIGHT);
@@ -447,8 +344,7 @@ int main(int argc,char *argv[])
 	gtk_box_pack_end(GTK_BOX(vbox),text,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(window),vbox);
 	/* ե */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
-														"<main>/ե(F)");
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
 	for (i=0;i<history && history_file[i]!=NULL;i++) {
 		menu_item=gtk_menu_item_new_with_label(history_file[i]);
 		gtk_signal_connect(GTK_OBJECT(menu_item),"activate",
@@ -468,7 +364,26 @@ int main(int argc,char *argv[])
 
 	/* ˵ưƤ뤫å */
 	if (!second) {
-		gtk_selection_convert(window,atom_videomaid,
+		for (i=1;i<argc;i++) {
+			if (arg_files[i-1]) {
+				arg=get_full_path(argv[i]);
+				leng=strlen(arg)*sizeof(gchar);
+				arg_text=g_realloc(arg_text,length+leng+sizeof(gchar));
+				memcpy(arg_text+length,arg,leng);
+				g_free(arg);
+			} else {
+				leng=strlen(argv[i])*sizeof(gchar);
+				arg_text=g_realloc(arg_text,length+leng+sizeof(gchar));
+				memcpy(arg_text+length,argv[i],leng);
+			}
+			length+=leng;
+			arg_text[length++]='\n';
+		}
+		if (length>0) {
+			arg_text[length-1]='\0';
+			gtk_selection_owner_set(window,atom_videomaid1,GDK_CURRENT_TIME);
+		}
+		gtk_selection_convert(window,atom_videomaid0,
 								GDK_SELECTION_TYPE_STRING,GDK_CURRENT_TIME);
 		gdk_threads_enter();
 		while (instance<0)
@@ -478,38 +393,21 @@ int main(int argc,char *argv[])
 		if (instance>0) {
 			/* ˵ưƤȤ */
 			gdk_threads_enter();
-			event.type=GDK_CLIENT_EVENT;
-			event.window=window->window;
-			event.send_event=TRUE;
-			event.message_type=atom_videomaid;
-			event.data_format=32;
-			event.data.l[0]=0;
-			event.data.l[4]=getpid();
-			gdk_event_send_clientmessage_toall((GdkEvent *)&event);
-			event.data_format=8;
-			for (i=1;i<argc;i++)
-				if (arg_files[i]) {
-					arg=get_full_path(argv[i]);
-					leng=strlen(arg)+1;
-					for (j=0;j<leng;j+=16) {
-						memcpy(event.data.b,arg+j,MIN(leng-j,16));
-						gdk_event_send_clientmessage_toall((GdkEvent *)&event);
-					}
-					g_free(arg);
-				}
+			while (arg_text!=NULL)
+				while (gtk_events_pending())
+					gtk_main_iteration();
 			gdk_threads_leave();
 			g_free(arg_files);
-			return 0;
+			gtk_exit(0);
 		}
-		gtk_signal_connect(GTK_OBJECT(window),"client-event",
-									GTK_SIGNAL_FUNC(signal_client_event),NULL);
-		gtk_selection_owner_set(window,atom_videomaid,GDK_CURRENT_TIME);
+		g_free(arg_text);
+		gtk_selection_owner_set(window,atom_videomaid0,GDK_CURRENT_TIME);
 	}
 
 	/* ɽ */
 	gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-												"<main>/(T)"))),FALSE);
+													"<main>/Task"))),FALSE);
 	gtk_widget_show_all(window);
 	gtk_widget_hide_all(text);
 	gtk_window_set_policy(GTK_WINDOW(window),FALSE,TRUE,TRUE);
@@ -539,18 +437,17 @@ int main(int argc,char *argv[])
 	}
 
 	/* ɥ */
-	j=0;
 	for (i=1;i<argc;i++)
-		if (arg_files[i]) {
+		if (arg_files[i-1]) {
 			open_file=g_malloc(sizeof(OpenFile));
 			open_file->file=g_strdup(argv[i]);
 			open_file->merge=file_merge;
 			pthread_create(&id,NULL,(void *)open_edit_file,open_file);
 			pthread_detach(id);
-			j++;
+			count++;
 		}
 	g_free(arg_files);
-	if (newfile && j<=0) {
+	if (newfile && count<=0) {
 		pthread_create(&id,NULL,(void *)open_edit_file,NULL);
 		pthread_detach(id);
 	}
@@ -614,11 +511,5 @@ int main(int argc,char *argv[])
 	g_free(save_path);
 	for (i=0;i<history;i++)
 		g_free(history_file[i]);
-	while (comm!=NULL) {
-		g_free(comm->arg);
-		p=comm->next;
-		g_free(comm);
-		comm=p;
-	}
 	return 0;
 }
