@@ -59,12 +59,6 @@ typedef struct {
 	GtkWidget *label;			/* ֤Υ٥ */
 	GtkWidget *menu_item;		/* ˥塼Υɥι */
 } VmaidWindow;
-typedef struct VmaidCommunication_Tag {
-	gchar *arg;
-	gint leng,init_line;
-	gint32 pid;
-	struct VmaidCommunication_Tag *prev,*next;
-} VmaidCommunication;
 
 
 enum {
@@ -84,17 +78,18 @@ extern gchar *history_file[10];			/* ե */
 extern gchar *open_path;				/* Υѥ */
 extern gchar *save_path;				/* ̾դ¸Υѥ */
 extern gchar *clipboard_scenario;		/* åץܡɤΥƥ */
+extern gchar *arg_text;					/* ץ̿ѿ */
 extern gint def_width,def_height;		/* ǥեȤΥɥΥ */
 extern gint history;					/* ե */
 extern gint instance;					/* ץ̿ѿ */
 extern gint default_view;				/* ɥν */
 extern guint default_rate;				/* ɥν */
 extern guint timer_id;					/* ID */
-extern VmaidCommunication *comm;		/* ץ̿ѹ¤ */
 extern GdkAtom atom_clipboard;			/* åץܡ */
 extern GdkAtom atom_targets;			/* å */
 extern GdkAtom atom_scenario;			/* ʥꥪ֥ */
-extern GdkAtom atom_videomaid;			/* ץ̿ѥȥ */
+extern GdkAtom atom_videomaid0;			/* ץ̿ѥȥ */
+extern GdkAtom atom_videomaid1;			/* ץ̿ѥȥ */
 extern GdkBitmap *bitmap0;				/* ط */
 extern GdkBitmap *bitmap1;				/* ط */
 extern GtkWidget *window;				/* ɥ */
